-- **************************************************
-- Provide Moho with the name of this script object
-- **************************************************

ScriptName = "Syn_ObjectColor"

-- **************************************************
-- General information about this script
-- **************************************************

Syn_ObjectColor = {}

function Syn_ObjectColor:Name()
	return "Object color"
end

function Syn_ObjectColor:Version()
	return "0.1"
end

function Syn_ObjectColor:Description()
	return "Quick toggle for editor object color"
end

function Syn_ObjectColor:Creator()
	return "(c)2021 J.Wesley Fowler (SynthSin75)"
end

function Syn_ObjectColor:UILabel()
	return "SYN: Object Color"
end

-- **************************************************
-- Recurring values
-- **************************************************

Syn_ObjectColor.once = false

-- **************************************************
-- Prefs
-- **************************************************

function Syn_ObjectColor:LoadPrefs(prefs)
	self.color1r = prefs:GetInt("Syn_ObjectColor.color1r", 0)
	self.color1g = prefs:GetInt("Syn_ObjectColor.color1g", 0)
	self.color1b = prefs:GetInt("Syn_ObjectColor.color1b", 0)
	self.color2r = prefs:GetInt("Syn_ObjectColor.color2r", 255)
	self.color2g = prefs:GetInt("Syn_ObjectColor.color2g", 255)
	self.color2b = prefs:GetInt("Syn_ObjectColor.color2b", 255)
end

function Syn_ObjectColor:SavePrefs(prefs)
	prefs:SetInt("Syn_ObjectColor.color1r", self.color1r)
	prefs:SetInt("Syn_ObjectColor.color1g", self.color1g)
	prefs:SetInt("Syn_ObjectColor.color1b", self.color1b)
	prefs:SetInt("Syn_ObjectColor.color2r", self.color2r)
	prefs:SetInt("Syn_ObjectColor.color2g", self.color2g)
	prefs:SetInt("Syn_ObjectColor.color2b", self.color2b)
end

-- **************************************************
-- Dialog
-- **************************************************

local Syn_ObjectColorDialog = {}

function Syn_ObjectColorDialog:new(moho)
	local d = LM.GUI.SimpleDialog("Choose obect colors", Syn_ObjectColorDialog)
	local l = d:GetLayout()
	
	local rgb1, rgb2 = LM.rgb_color:new_local(), LM.rgb_color:new_local()
	rgb1.r, rgb1.g, rgb1.b = Syn_ObjectColor.color1r, Syn_ObjectColor.color1g, Syn_ObjectColor.color1b
	rgb2.r, rgb2.g, rgb2.b = Syn_ObjectColor.color2r, Syn_ObjectColor.color2g, Syn_ObjectColor.color2b
	
	l:PushH()
		l:PushV()
		l:AddChild(LM.GUI.StaticText("Color 1"), LM.GUI.ALIGN_LEFT)
		l:AddChild(LM.GUI.StaticText("Color 2"), LM.GUI.ALIGN_LEFT)
		l:Pop()
		l:AddPadding(25)
		l:PushV()
		d.col1 = LM.GUI.ShortColorSwatch(false, 0)
		l:AddChild(d.col1)
		d.col1:SetValue(rgb1)
		d.col2 = LM.GUI.ShortColorSwatch(false, 0)
		l:AddChild(d.col2)
		d.col2:SetValue(rgb2)
		l:Pop()
	l:Pop()
	
	return d
end

function Syn_ObjectColorDialog:OnOK()
	Syn_ObjectColor.color1r = self.col1:Value().r
	Syn_ObjectColor.color1g = self.col1:Value().g
	Syn_ObjectColor.color1b = self.col1:Value().b
	Syn_ObjectColor.color2r = self.col2:Value().r
	Syn_ObjectColor.color2g = self.col2:Value().g
	Syn_ObjectColor.color2b = self.col2:Value().b
end

-- **************************************************
-- The guts of this script
-- **************************************************

function Syn_ObjectColor:Run(moho)
	if (not self.once) then
		self.once = true
		local dlog = Syn_ObjectColorDialog:new(moho)
		if (dlog:DoModal() == LM.GUI.MSG_CANCEL) then
			return
		end
	else
		if (MOHO.MohoGlobals.ElemCol.r == Syn_ObjectColor.color1r and MOHO.MohoGlobals.ElemCol.g == Syn_ObjectColor.color1g and MOHO.MohoGlobals.ElemCol.b == Syn_ObjectColor.color1b) then
			MOHO.MohoGlobals.ElemCol.r = Syn_ObjectColor.color2r
			MOHO.MohoGlobals.ElemCol.g = Syn_ObjectColor.color2g
			MOHO.MohoGlobals.ElemCol.b = Syn_ObjectColor.color2b
		else
			MOHO.MohoGlobals.ElemCol.r = Syn_ObjectColor.color1r
			MOHO.MohoGlobals.ElemCol.g = Syn_ObjectColor.color1g
			MOHO.MohoGlobals.ElemCol.b = Syn_ObjectColor.color1b
		end
	end
end
